<li class="group">
  <div class="help-sample"><a class="internal">citation</a></div>
  <div class="help-text">Link within a regulation <br/>
      (example: {{ cfr_part }}.8(b))<br />
      (Open it to go to that section.)</div>
</li>
