{% comment %}
    "Notes" found in appendices. Note that this should be kept until
    appendices use the NOTE node type
{% endcomment %}
<div class="appendix-note inline-interpretation">
    <h4>Note{{ lines|pluralize }}:</h4>
    <ol>
        {% for line in lines %}
        <li>{{ line }}</li>
        {% endfor %}
    </ol>
</div>
