{% comment %}
    Links to definitions in the regulation text. 
{% endcomment %}
<a href="{{citation.url}}" class="citation definition" data-definition="{{citation.definition_reference}}" data-defined-term="{{citation.term}}">{{citation.label}}</a>
