<li><a href="{{item.url}}" data-section-id="{{item.section_id}}" id="nav-{{item.section_id}}">
        <span class="toc-section-marker">{% if item.is_section_span%}§§&nbsp;{% else %}§&nbsp;{% endif %}{{item.label}}</span> {{item.sub_label|safe}}
</a></li>
