{% comment %}
Lists footnotes at the bottom of a section. Assumes the "footnotes" variable
is defined as a list.
{% endcomment %}
{% if footnotes %}
<div class="footnote-box">
    <h5>Footnotes</h5>
    <ul class="footnotes">
        {% for footnote in footnotes %}
        <li id="footnote-{{footnote.ref}}">
            <span class="reference-num">{{footnote.ref}}.</span>
            <p>
                {{footnote.note}}
            </p>
        </li>
        {% endfor %}
    </ul>
</div>
{% endif %}
