{% comment %}
    These are essentially headers that appear with the definitions in the reg body.
{% endcomment %}
<dfn class="key-term" dfn-key-term="{{key_term.phrase}}">{{key_term.key_term}}</dfn>
