<li><h3 class="toc-nav__divider" data-section-id="{{item.section_id}}">{{item.label|safe|upper}}</h3></li>

{% if item.sub_toc %}
    {% for item in item.sub_toc %}
        {% if item.is_section %}
            {% include "regulations/toc-section.html" %}
        {% else %}
            <li><a href="{{item.url}}" data-section-id="{{item.section_id}}">{{item.label|safe}}</a></li>
        {% endif %}
    {% endfor %}
{% endif %}

