.note {
  background-color: $gray_lightest;
  padding: 1em;
  padding-left: -40px;
  // 40px is the amount of indentation per ol level
  // This makes notes look flush with their parent

  h4 {
    margin-top: 0;
  }
}

.footnote-box {
  background-color: $gray_lightest;
  padding: 1.5em;
  margin-left: 20px;

  h5 {
    margin-top: 0;
    color: $gray_darker;
    @include sans-font-bold;
  }

  .footnotes {
    border: none;

    li {
      border: none;

      p {
        line-height: 1.65em;
        margin: 0 0 1em 1.5em;
      }
    }
  }
}
