/*
Global Footer
============
*/

.application-footer {
  padding: 15px;
  margin-left: 285px;
  @include sans-font-regular;
  color: $gray_darker;

  abbr[title] {
    border-bottom: none;
  }

  &.active {
    margin-left: 80px;
  }

  .title-logo {
    display: none;
  }
}

/*
Landing Page Footer
===================
*/


.landing-footer {
  margin: 3em 0;
  padding-top: 2em;
  @include border-top-medium ($width: 2px);
  @include sans-font-regular;
  font-size: 0.875em;

  .logo-wrap {
    width: 20%;
    float: left;
  }

  .footer-links {
    float: right;
    width: 75%;
    padding-top: 9px;
  }
}

.primary-footer-list {
  @include reset;

  li {
    display: inline;
  }

  li + li::before {
    content: ' | ';
    padding: 0 10px;
  }
}

.secondary-footer-list {
  @include reset;
  display: block;
  float: left;
  margin-right: 2em;
  margin-top: 1em;

  li {
    @include reset;
    margin-top: .25em;
  }
}

/*
Next/Previous Links
===================
*/

.section-nav {
  margin-top: 50px;
}

.footer-nav {
  margin-bottom: 150px;
}

// styles for both the next and previous blocks
.next-prev {
  border-top: 2px solid $gray_light;
  width: 45%;
  @include sans-font-bold;
}

.pager {
  @include sans-font-regular;
  color: $gray_darker;
  text-align: center;
}

.previous {
  float: left;
  padding: 0 15px;
  margin-left: -15px;

  .cf-icon-left {
    font-size: 0.875em;
    margin-left: -15px;
    margin-top: 6px;
    float: left;
  }
}

.next {
  float: right;
  text-align: right;
  padding: 0 15px;

  .cf-icon-right {
    font-size: 0.875em;
    margin-right: -15px;
    margin-top: 6px;
    float: right;
  }
}

/*
Link Styles
-----------
*/

.next-prev-link {
  display: block;
  @include next-prev-link-link-font;
  margin: 16px 0 0 0;
}

.next-prev-link:link,
.next-prev-link:visited {
  color: $action_color;
  text-decoration: none;
}


/*
Small Screens
-------------
*/

@media only screen and (max-width: 480px) {
  .section-nav {
    .next-prev {
      font-size: 1.125em;
    }
  }

  .footer-nav {
    margin-bottom: 50px;
  }

  .application-footer {
    .title-logo {
      display: block;
      margin-bottom: 1em;

      h1 {
        font-size: 1em;
        margin-bottom: 1em;
      }
    }
  }
}

@media only screen and (max-width: 600px) {
  .section-nav {
    margin-top: 1.5em;
  }

  .footer-nav {
    margin-bottom: 60px;
  }

  .next-prev {
    border-top: none;
    margin-bottom: 1.5em;
  }

  .next-prev-title {
    display: none;
  }

  .next-prev-label {
    display: none;
  }

  .previous {
    margin-left: -25px;
  }
}

@media only screen and (max-width: 780px) {
  .landing-footer {

    .logo-wrap {
      width: 100%;
      float: none;
    }

    .footer-links {
      width: 100%;
      float: none;
    }
  }
}

@media only screen and (max-width: 1100px) {
  .application-footer {
    margin-left: 40px;
  }
}
