/*
Sass Mixins
 ==========================================================================
mixins.scss contains complex mixins to be used throughout the Sass files
*/

// Drawer font styles
@mixin drawer-header-font {
  @include sans-font-bold;
  color: $gray_darkest;
  font-size: 0.875em; // 12px / (26px * .875em)
  text-transform: uppercase;
}

// Regulation nav (drawer) font styles
@mixin regulation-nav-section-marker-font {
  @include sans-font-bold;
  display: block;
  font-size: 18px;
}

@mixin regulation-nav-interp-heading-font {
  @include sans-font-regular;
  text-transform: uppercase;
  font-size: 12px;
}

@mixin regulation-nav-interp-title-font {
  @include sans-font-bold;
  font-size: 14px;
}

// History (drawer) font styles
@mixin regulation-history-version-date-font {
  @include sans-font-bold;
  font-size: 1.285714286em;
}


// Navigation links
@mixin next-prev-link-link-font {
  font-size: 0.875em;
}

// Border Styles
@mixin border-bottom-medium($width: 1px) {
  border-bottom: $width solid $panel_border_color;
}

@mixin border-bottom-light($width: 1px) {
  border-bottom: $width solid $panel_border_color;
}

@mixin border-bottom-dark($width: 1px) {
  border-bottom: $width solid $panel_border_color;
}

@mixin border-top-light($width: 1px) {
  border-top: $width solid $panel_border_color;
}

@mixin border-top-medium($width: 1px) {
  border-top: $width solid $panel_border_color;
}

@mixin border-right-light($width: 1px) {
  border-right: $width solid $panel_border_color;
}

// Animations
@mixin slide($direction: left, $speed: 300ms) {
  transform: translate3d(0, 0, 0);
  -webkit-transition: $direction $speed ease;
  -moz-transition: $direction $speed ease;
  -ms-transition: $direction $speed ease;
  -o-transition: $direction $speed ease;
  transition: $direction $speed ease;
}

// utility class for spinning loading indicators
@mixin u_spinner {
  @extend .cf-icon;
  @extend .cf-icon__spin;
  display: block;
  width: 1em;
  height: 1em;
  margin: 0 auto;
  content: '\e112';
  color: $primary_color;
  text-align: center;
  font-size: 1.375em;
  margin-top: 2em;
}

// Helpers
@mixin reset {
  margin: 0;
  padding: 0;
}
