{% comment %}
  Footnotes are displayed as hover text and as links to the footnote text.
  Many of the styles here match regulations/layers/sxs-footnotes.html
{% endcomment %}
<sup><a id="footnote-jump-{{ref}}" class="footnote-jump-link standard" href="#footnote-{{ref}}" title="{{ note }}">[{{ ref }}]</a></sup>
