{% load render_nested %}

<section data-cache-key="sidebar" data-cache-value={{label_id}}">
{% for sidebar in sidebars %}
  {% render_nested template=sidebar.template_name context=sidebar %}
{% endfor %}

{% block additional-rhs %}{% endblock %}
</section>
