<a href="{{url}}" class="external {{classes}}" target="_blank"
   {% if title %}
   title="{{title}}" aria-label="{{title}}, Link opens in a new window"
   {% else %}
   aria-label="{{text}}, Link opens in a new window"
   {% endif %}
>{{text}}</a>
