# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-18 15:49
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('regulations', '0002_remove_failedcommentsubmission_files'),
    ]

    operations = [
        migrations.DeleteModel(
            name='FailedCommentSubmission',
        ),
    ]
