<header class="expandable group">
    <h4 tabindex="0">Help</h4>
    <a href="#" tabindex="0"><span class="icon-text">Show/Hide Contents</span></a>
</header>
<div class="chunk expand-drawer start-collapsed">
    <div class="sidebar-subsection">
        <h5 class="help-title">Interface Help</h5>
        <a class="what" href="{% url 'about' %}#navigation" aria-label="Link opens in a new window" target="_blank">(What's this?)</a>

        <ul class="help-list">
            <li><span class="cf-icon cf-icon-table-of-contents help-icon"></span>Table of contents</li>
            <li><span class="cf-icon cf-icon-history help-icon"></span>Regulation Timeline</li>
            <li><span class="cf-icon cf-icon-search help-icon"></span>Search</li>
            <li><span class="cf-icon cf-icon-left help-icon"></span>Hide Navigation</li>
            <li><span class="cf-icon cf-icon-right help-icon"></span>Show Navigation</li>
        </ul>
    </div> <!-- /.sidebar-subsection-->
