@media print {

  // Typography
  body {
    font-size: 11pt;
    line-height: 14pt;
  }

  @page {
    margin-top: .5in;
    margin-bottom: .5in;
    margin-left: 1in;
    margin-right: 1in;
  }

  // IE garbles Avenir when saving to a PDF, so we have to manually add
  h1,
  h2,
  h3,
  h4,
  h5,
  dfn,
  strong,
  .main-content ol,
  .key-term,
  .defined-term,
  .error p,
  .error li,
  .inline-interpretation .ref-num,
  .banner-text,
  .header-label,
  .landing p,
  .landing li,
  .landing-curent-link a,
  .alert a,
  .search-nav a,
  .secondary-content,
  .chunk li a,
  .open-definition ol,
  .active-term,
  .reference-num,
  .analysis-list a,
  .sxs-metadata,
  .reg-header {
    .lt-ie9 & {
      font-family: Arial, sans-serif !important;
    }
  }

  // ensure that styling the list markers doesn't override the body font style
  .main-content p {
    font-family: $body_font !important;
  }

  // Page Breaks & Orphans
  h1,
  h2,
  h3,
  h4 {
    page-break-after: avoid;
  }

  p {
    orphans: 3;
  }

  // Hidden Elements
  nav,
  #table-of-contents,
  .panel,
  #menu-link,
  .hidden,
  .main-head,
  .toc-head,
  .header-main,
  .next-prev,
  .regs-meta,
  .sxs-back-button {
    display: none !important;
  }

  .reg-header,
  .main-head,
  .sub-head {
    position: static;
  }

  .reg-header {
    height: auto;
    border-bottom: 0;
  }

  .effective-date {
    padding-right: 0;
  }

  img,
  footer {
    display: none;
  }

  footer.search-nav {
    display: block;
  }


  /*
  Single Column Layout
  ==========================================================================
  Print only the text of the regulation
  */

  #preamble-read {
    width: 100%;
    padding: 0 40px;
    margin: 0 auto;

    .activate-write {
      display: none;
    }

    //removes indent on the first level of depth
    .preamble-content > ul {
      padding: 0;
    }
  }

  .wrap,
  .main-content,
  .secondary-content,
  .sxs-main-content,
  .sxs-metadata {
    position: static;
    max-width: 100%;
    width: 100%;
    float: none !important;
    margin: 0;
    padding: 0;
  }

  // overrides dynamic sizing done by the DataTables plugin which breaks in print mode

  .dataTables_scrollHeadInner {
    width: 100% !important;

    table {
      width: 100% !important;
    }
  }

  // Margin/Padding Resets
  body,
  .wrap {
    margin: 0;
    padding: 0;
  }

  // Heading/Keyword Styles
  h1 {
    font-size: 26pt;
    line-height: 30pt;
  }

  .section-title {
    font-size: 20pt;
    line-height: 26pt;
    margin-top: 15px;
  }

  .level-1 .key-term {
    font-size: 1em;
    line-height: 1.5;
  }

  /*
   Link Styles
   ==========================================================================
   Remove link styles from definitions & citations
  */
  a.definition:link,
  a.definition:visited,
  a.citation:link,
  a.citation:visited {
    border-bottom: none;
    color: $black;
  }

  a[href^="http://"] {
    background: none;
    padding-right: 0;
  }
  a.external::after {
    content: none;
  }

  @media (-webkit-min-device-pixel-ratio: 2), (min-resolution: 192dpi) {
    a[href^="http://"] {
      background: none;
    }
  }

  /*
   Inline Interpretations & Definitions
   ========================================================================== */

  .inline-interpretation {
    background: $gray_lightest;
    border: 1px solid $gray_lightest;

    .hidden {
      .js & {
        display: block !important;
      }
    }

    .expand-button {
      display: none;
    }

    .definition:link {
      border-bottom: none;
    }

    .section-link {
      display: none;
    }
  }

  .open-definition {
    position: relative;
    padding: 0;
    margin: 10px;
    border: 1px solid $gray_light;

    .definition-text p:before {
      content: '*';
    }
  }

  .secondary-content {
    border-left: none;
  }

  .definition.active:after {
    content: '*';
  }


  // Layout Styles/Resets
  .level-1 > li {
    border-bottom: none;
    padding: .5em 0;
  }

  .main-content {
    border-right: none;
  }

  .regs-meta {
    position: relative;
  }

  .reg-section:before,
  .appendix-section:before,
  .supplement-section:before {
    height: 0;
    margin: 0;
  }

  .reg-text > section {
    border-bottom: none;
  }

  .sidebar-inner {
    padding-bottom: 0;
  }

  // Reset internal navigation offsets
  .reg-section .level-1 li,
  .appendix-section .level-1 li,
  .supplement-section .level-1 li {
    border-top: 0;
    margin-top: 0;
  }

  // Section by Section Styles/Resets
  .sxs {
    padding-bottom: 0;
  }

  #breakaway-view.open-sxs,
    .full-breakaway {
      overflow-y: auto;
    }

    .sxs-header {
      position: static;
      width: 100%;
      height: 2.125em;
      background-color: none;
      border-bottom: 0;
    }

  #breakaway-view.open-sxs,
  .open-sxs,
  .full-breakaway {
    position: static;
    top: 0 !important;
    left: 0;
    width: auto;
    height: auto;
    min-height: auto;
    background: none;
  }

  // eRegs Home Page Styles/Resets
  .hero-header,
  .hero-text,
  .read-more-link,
  .reg-list {
    line-height: 1.5
  }

  .landing-content {
    margin-top: 0;

    .content-primary,
    .content-secondary {
      width: 100%;
    }
  }

  .notices {
    min-height: 0;
  }

  .hero {
    background-color: $white;

    .inner-wrap {
      height: 180px;
    }
  }

  // eRegs About Page Styles/Resets
  .about-content {
    img {
      display: inline-block;
    }

    .about-section {
      padding: 2em 0;
    }

    .easy-read {
      margin-top: 2em;
    }

    .column-3 {
      width: 100%;
      margin: 0 10px;
    }
  }

  #related-info .content-primary,
  #related-info .content-secondary {
    width: 48%;
  }

  .dev-well .cf-icon-github {
    height: 20px;
  }

  .title-hero {
    background-color: $white;
  }
}
