<section id="print_part" class="regs-meta">
  <header class="group">
    <a href="{% url 'chrome_regulation_view' cfr_part version %}?print=true">
      <h4>
        Print <strong>{{ cfr_title }} CFR Part {{ cfr_part }}</strong>
        <span class="cf-icon cf-icon-print" />
      </h4>
    </a>
  </header>
</section>
