{% comment %}
    Wrapper for EXTRACT nodes. Wraps them in an appropriate DIV, surrounded by
    an LI
{% endcomment %}

<li
    {% if node.marker %}marker-type="{{node.marker}}"{% endif %}
    {% if not inline %}id="{{node.markup_id}}" data-permalink-section{% endif %}
    {% if node.interp %}data-interp-id="{{node.interp.markup_id}}"{% endif %}
    {% if node.stars_collapse %}data-stars="{{node.stars_collapse}}"{% endif %}
>
    <div class="extract">
        {% include "regulations/node.html" %}
    </div>
</li>
