{% comment %}
DAP Analytics tag.
{% endcomment %}

{% if EREGS_GLOBALS.ANALYTICS.DAP.DAP_URL_PARAMS %}
  <script src="https://dap.digitalgov.gov/Universal-Federated-Analytics-Min.js?{{ EREGS_GLOBALS.ANALYTICS.DAP.DAP_URL_PARAMS }}" id="_fed_an_ua_tag"></script>
{% endif %}
