<div class="cfr-wrapper">

  {% for instruction in instructions %}
    <div class="cfr-instructions">
      {{ instruction }}
    </div>
  {% endfor %}

  {% for authority in authorities %}
    <div>
      <strong>Authority</strong>: {{ authority }}
    </div>
  {% endfor %}

  {% for subpart in subparts %}
  <h5 class="subpart-addition">
    <ins>Subpart {{subpart.letter}} &mdash; {{subpart.title}}</ins>
  </h5>
  <div class="subpart-info">
    <div class="subpart-wayfinding">
      {% for url in subpart.urls %}
        <a href="{{url}}"
           aria-label="{{forloop.counter}} of {{subpart.urls|length}} sections"
           {% if forloop.counter0 == subpart.idx %}class="current"{% endif %}
         >&nbsp;</a>
      {% endfor %}
    </div>
    <p class="subpart-sections">This is section
      <strong>{{subpart.idx|add:"1"}} of {{subpart.urls|length}}</strong>
      in subpart {{subpart.letter}}
    </p>
  </div>
  {% endfor %}

  {% if tree %}
    {% with c=tree %}
    {% include "regulations/regulation_text.html" %}
    {% endwith %}
  {% endif %}

</div>
