<div id="content-body" class="main-content">
    <section id="content-wrapper">
        <section data-base-version="{{ current_version.version }}" class="landing" data-page-type="landing-page" data-reg-part="{{reg_part}}" id="{{reg_part}}">
            {% block reg_title %}
            {% endblock %}

            {% if new_version %}
            <div class="alert effective-alert group">
              <div class="alert_effective-date">
                  New amendments effective: <strong>{{new_version.by_date|date:"n/j/Y"}}</strong>
              </div>
              <div class="alert_view-link">
                  <a href="{% url 'chrome_section_view' reg_first_section new_version.version %}" class="go">View amended regulation</a></li>
              </div>
            </div><!--/.alert-->
            {% endif %}

            {% block reg_main_content %}
            {% endblock %}
            {% block reg_addtl_content %}
            {% endblock %}

            <div id="disclaimer">
                {% block legal_disclaimer %}
                {% endblock %}
            </div>
        </section>
    </section>
</div>


<div id="sidebar" class="secondary-content">
    <div id="sidebar-content" class="sidebar-inner">
    <section id="definition" class="regs-meta"></section>
    <section class="landing-sidebar">

        {% block reg_sidebar %}
        {% endblock %}
    </section>
    </div>
</div>
