{% comment %}
    Include the original marker in a class (for ease of hiding) and the marker
    with a period, which is what we'll display.

    This template is for backwards compatibility. It'll be removed soon.
{% endcomment %}
<span class="stripped-marker">{{ paragraph_stripped }}.</span><span class="paragraph-marker">{{ paragraph }}</span>
