{% extends "regulations/chrome.html" %}

{% block title %}
Search of {{reg_part}} for {{q}} | eRegulations
{% endblock %}

{% block active_title %}
<em class="header-label">
<span class="subpart">Search results</span> {{ results.total_hits }} result{{ results.total_hits|pluralize }}
</em>
{% endblock %}
