{% extends "regulations/preamble-base.html" %}

{% block title %}Preamble {{doc_number}}{% endblock %}

{% block chrome-content %}
<main role="main">

  <div id="content-body" class="main-content preamble-wrapper">
    <section id="content-wrapper">
      <noscript>
        <div class="error">
          Javascript is currently required to <em>submit</em> comments through
          this system. To find alternative comment submission methods, please
          read the agency instructions as listed in the preamble. We apologize
          for the inconvenience, but hope to remove this limitation soon.
        </div>
      </noscript>
      {% include "regulations/preamble-partial.html" %}
    </section>
  </div> <!-- /.main-content -->

</main>
{% endblock %}
