
<section class="error section-not-found" data-base-version="{{version}}" data-page-type="error">
    <h3>Section does not exist.</h3>

    <p>Section {{reg_section}} does not exist in the regulation effective {{effective_date|date:"n/j/Y"}}.</p>

    <ul>
        <li><span class="cf-icon cf-icon-history"></span>Try a different effective date of the regulation</li>
        <li><span class="cf-icon cf-icon-table-of-contents"></span>View another section of the regulation</li>
        <li><span class="cf-icon cf-icon-search"></span>Or, try searching the regulation </li>
    </ul>
</section> <!--.error-->
