<section id="sxs-list" class="regs-meta">
  <header id="sxs-expandable-header" class="expandable sxs-expand group{% if analyses %} has-content open{% endif %}">
    <h4 tabindex="0">Section-by-section Analysis</h4>
    <a href="#" tabindex="0"><span class="icon-text">Show/Hide Contents</span></a>
  </header>
  {% if analyses %}
  <div class="chunk expand-drawer">
    <h5 class="subtitle">Most Recent Analysis</h5>
    <a class="what" href="{% url 'about' %}#related-info" aria-label="Link opens in a new window" target="_blank">(What's this?)</a>
    <ul class="divided-list">
    {% for analysis in analyses %}
      <li><a class="sxs-link" href="{% url 'chrome_sxs_view' analysis.label_id analysis.doc_number %}?from_version={{ version }}" data-sxs-paragraph-id="{{analysis.label_id}}" data-doc-number="{{analysis.doc_number}}">{{analysis.text}}<span class="cf-icon cf-icon-right"></span></a></li>
    {% endfor %}
    </ul>
  </div>
  {% else %}
  <div class="chunk expand-drawer start-collapsed">
    No analyses available for {{ human_label_id }} in this tool. <a class="what" href="{% url 'about' %}#related-info" aria-label="Link opens in a new window" target="_blank">(What's this?)</a>
  </div>
  {% endif %}
</section> <!-- /.regs-meta -->

