{% extends "regulations/chrome.html" %}

{% block title %}
{{meta.cfr_title_number}} CFR Part {{reg_part}} | eRegulations
{% endblock %}

{% comment %}
Does not wrap the content in a #content-body; this is instead provided by the
landing page content (which also provides the sidebar).
{% endcomment %}

{% block chrome-content %}
{{ main_content|safe }}
{% endblock %}

{% comment %}
The landing page sidebar contains reg specific information in place of
regulation text interactions
{% endcomment %}
{% block chrome-sidebar %}{% endblock %}