{% comment %}
    Default wrapper for nodes -- put them in a LI
{% endcomment %}

<li
    {% if node.marker %}marker-type="{{node.marker}}"{% endif %}
    {% if node.toc_id %}data-toc-id="{{node.toc_id}}"{% endif %}
    {% if node.human_label %}data-label="{{node.human_label}}"{% endif %}
    {% if not inline %}id="{{node.markup_id}}" data-permalink-section{% endif %}
    {% if node.interp %}data-interp-id="{{node.interp.markup_id}}"{% endif %}
    {% if node.stars_collapse %}data-stars="{{node.stars_collapse}}"{% endif %}
>
    {% include "regulations/node.html" %}
</li>
