/*
 About
 ==========================================================================
 about.scss defines the visual appearance of the eRegulations about page
 */

// about-content is the same as landing-content, these should be unified into one class
.about-content {
  margin-top: 60px;
  @include sans-font-regular;


  h3 {
    margin: 0 0 30px 0;
  }

  // offset persistent header
  .inner-wrap:before {
    display: block;
    content: '';
    height: 60px;
    margin-top: -60px;
    visibility: hidden;
  }
}

// hero
.title-hero {
  background-color: $blue_lighter;
  @include border-bottom-light;

  h3 {
    font-size: 34px;
    padding: 24px 0;
    margin: 0;
    @include sans-font-regular;
  }
}

.about-section {
  border-bottom: 1px solid $gray_light;
  padding: 4em 0;

  .inner-wrap {
    padding: 0 1em;
  }
}

.about-section:last-child {
  border-bottom: 0;
}


.easy-read {
  margin-top: 4em;
}

.dev-well {
  h3 {
    @include reset;
    font-size: 1em;
    line-height: 24px;
    text-transform: uppercase;
  }

  p {
    @include reset;
    font-size: 0.875em;
  }

  .cf-icon-github {
    float: left;
    display: block;
    height: 100px;
    margin-right: 16px;
    font-size: 1.5em;
    color: $gray_dark;
  }
}

// snazzy ordered lists
.about-ol {
  counter-reset: li;
  list-style: none;
  *list-style: decimal; // use default numbering for IE6/7
  position: relative;
}

.about-ol > li {
  margin: 1em 0 3em 0;
}

.about-ol > li:last-child {
  margin-bottom: 0;
}

.about-ol > li:before {
  content: counter(li);
  counter-increment: li;
  background: $blue;
  color: $white;
  font-size: 12px;
  position: absolute;
  text-align: center;
  left: -1em;
  height: 20px;
  width: 20px;
  line-height: 20px;
  border-radius: 20px;
}

// custom styles
.easy-nav {
  padding-left: 60px;
  position: relative;
}

.icon-callout {
  position: absolute;
  top: 0;
  left: 0;
  width: 46px;
  height: 46px;
  line-height: 46px;
  border-radius: 4px;
  text-align: center;
  background: $gray_lightest;
  color: $gray_dark;
  font-size: 22px;
}

@media only screen and (min-width: 780px) {
  .about-screenshot {
    margin-bottom: -70px; // align with border on larger screens
  }
}

.about-timeline {
  margin-left: 20px;
}

.about-timeline:before {
  font-family: 'CFPB Minicons';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  content: '\e642';
  color: $blue;
  margin-left: -32px;
  padding-right: 12px;
  font-size: 18px;
}

.small-disclaimer {
  display: block;
  color: $gray_dark;
  line-height: 1.4;
}


// Smaller Screen Styles
@media only screen and (max-width: 780px) {
  // less section padding
  .about-section {
    padding: 2em 0;
  }

  .easy-read {
    margin-top: 2em;
  }

  // hidden
  .responsive-img {
    display: none;
  }

  // Spacing
  .title-hero {
    margin-bottom: 0;
  }

  .easy-nav {
    margin-bottom: 2em;
  }

  .learn-more {
    margin-top: -1em;
  }

  .about-ol {
    margin-left: 1em;
  }

  .about-timeline {
    padding-left: 1em;
  }

  // styles
  .about-section {
    border-bottom: 0;
  }

}

// Smallest Screen Styles
@media only screen and (max-width: 460px) {
  .title-hero {
    h2 {
      font-size: 26px;
      padding: 12px 0;
    }
  }
}
