.expand-button {
  color: $blue_light;
  @include sans-font-bold;
  display: inline-block;
  text-transform: uppercase;
  font-size: 0.8em;
  cursor: pointer;
}

.expand-button:before {
  @extend .cf-icon;
  content: '\e109';
  float: right;
  padding-left: 6px;
}

.open.expand-button:before {
  content: '\e111';
}
