{% extends "regulations/base.html" %}

{% block title %}
Analysis for {{formatted_id}} | eRegulations
{% endblock %}

{% block body %}

{% comment %}
    Page-level template for breakaway views with chrome. Right now, this only includes section-by-section analysis.
    If another type of content displays via this template, data-page-type should change to something like "breakaway-{{type}}"
    where type is "sxs" or "fr-notice", etc.
{% endcomment %}
<section class="full-breakaway" data-base-version="{{version}}" data-page-type="breakaway-sxs">
    <header id="site-header" class="reg-header chrome-header">
        {% include "regulations/main-header.html" %} 
    </header>

    <div id="breakaway-view">{{ partial_content|safe }}</div>
</section>

{% endblock %}
