{% load static from staticfiles %}

{% comment %}
    Model form images
{% endcomment %}
<a href="{{ url }}">
    <img class="reg-image" alt="{{ alt }}" src="{%static "regulations/img/bg.gif" %}" data-original="{% if thumb_url %}{{ thumb_url }}{% else %}{{ url }}{% endif %}"/>
    <noscript><img class="reg-image" alt="{{ alt }}" src="{% if thumb_url %}{{ thumb_url }}{% else %}{{ url }}{% endif %}" /></noscript>
</a>
