<section id="content-wrapper" class="reg-text">
{% if tree.children %}
    {% for c in tree.children %}
        {%include "regulations/subpart.html" %}
        {%include "regulations/appendix.html" %}
        {%include "regulations/interpretations.html" %}
        {%include "regulations/navigation.html"%}
    {% endfor %}
{% endif %}
</section> <!-- /.reg-text -->
