/*
Full footer styles
 ==========================================================================
full-footer.scss contains styles for footer used on the universal landing and about pages */

.reg-footer {
/*
	Footer tag should have class .reg-footer (i.e. <footer class="reg-footer"></footer>)
*/
}
